#!/bin/sh
#
# rblmtpd GREETDELAY (UN)INSTALL Script (install_greetdelay.sh)
# ---------------------------------------------------------------
#
# Purpose:      To install and uninstall the rblmtpd Greetdelay Patch
#
# Parameters:   -u (uninstall)
#	        VRF (Version to be uninstalled)
#
# Usage:        ./install_greetdelay.sh [-u] [Version]
#
#		Installation: 	./install_greetdelay.sh
# 		Uninstallation: ./install_greetdelay.sh -u 105
#
# Return Codes: 0 - Patches applied successfully
#		1 - Original ucspi-tcp files not found (Patch not extracted in ucspi-tcp source directory)
#		2 - Patch files not found 
#
# Output:	install_greetdelay.log
#
# History:      1.0.0 - Erwin Hoffmann - Initial release
#		1.0.1 - 	       - grep fix; Gentoo fix
#		1.0.2 -			 removed '-v' optio for cp
#
#---------------------------------------------------------------------------------------
#
DATE=$(date)
LOCDIR=${PWD}
CONFHOME=$(head -n 1 conf-home)
SOLARIS=$(sh ./find-systype.sh | grep -ci "SunOS")
LOGFILE=greetdelay.log
TARGETS=FILES.greetdelay
IFSKEEP=${IFS}
REL=04 # Should be identical to rblmtpd GREETDELAY level
BUILD=20081022172937


if [ $# -eq 0 ] ; then

	echo "Installing rblmtpd GREETDELAY $REL (Build $BUILD) at $DATE <<<" | tee -a $LOGFILE 2>&1 

	for FILE in $(grep "^= " ${TARGETS} | awk '{print $2}'); do
		echo "Targeting file $FILE ..." | tee -a $LOGFILE 2>&1
		if [ -s ${FILE} ] ; then
			cp ${FILE} ${FILE}.$REL | tee -a $LOGFILE 2>&1
			echo "--> ${FILE} copied to ${FILE}.$REL" | tee -a $LOGFILE 2>&1
		else
			echo "${FILE} not found !"
			exit 1
		fi
		if [ -s ${FILE}.patch ] ; then
			if [ ${SOLARIS} -gt 0 ]; then
				echo "--> Patching source file ${FILE} for Solaris ...." | tee -a $LOGFILE 2>&1
				patch -i ${FILE}.patch ${FILE} 2>&1 | tee -a $LOGFILE
			else
				echo "--> Patching source file ${FILE}  ...." | tee -a $LOGFILE 2>&1
				patch ${FILE} ${FILE}.patch 2>&1 | tee -a $LOGFILE
			fi
		else
			echo "!! ${FILE}.patch not found !"
			exit 2
		fi
	done 

	for FILE in $(grep "^! " ${TARGETS} | awk '{print $2}'); do
		echo "Targeting file $FILE ..." | tee -a $LOGFILE 2>&1	
		MANCAT=$(echo ${FILE} | awk -F"." '{print $NF}')
		if [ -s ${FILE} ] ; then
			gzip ${FILE}
			cp -v ${FILE}.gz /usr/share/man/man${MANCAT}/
		fi
	done

	echo "Installation of rblmtpd GREETDELAY $REL (Build $BUILD) finished at $DATE <<<" | tee -a $LOGFILE 2>&1 

# Now go for the uninstallation....

elif [ "$1" = "-u" ] ; then

# Get the Version Number from INPUT 

	if [ $# -eq 2 ] ; then
		REL=$2
	fi

	echo "De-installing rblmtpd GREETDELAY $REL (Build $BUILD) at $DATE <<<" | tee -a $LOGFILE 2>&1 

	for FILE in $(grep "^= " ${TARGETS} | awk '{print $2}'); do
		echo "Targeting file $FILE ..." | tee -a $LOGFILE 2>&1
		if [ -s ${FILE}.$REL ] ; then
			mv ${FILE}.$REL ${FILE} | tee -a $LOGFILE 2>&1
			touch ${FILE}
			echo "--> ${FILE}.$REL moved to ${FILE}" | tee -a $LOGFILE 2>&1
		else
			echo "!! ${FILE}.$REL not found !"
		fi
	done
	echo "De-installation of rblmtpd GREETDELAY $REL (Build $BUILD) finished at $DATE <<<" | tee -a $LOGFILE 2>&1 
fi

exit 0
